@@ -1703,8 +1703,8 @@ typedef int pid_t;
   * The threadsafe resolver(5) API came out before 2002, and should be on by
   * default.
   */
-#ifndef NO_RES_NINIT
-#define USE_NRES_INIT
+#ifndef NO_RES_NCALLS
+#define USE_RES_NCALLS
 #endif
 
  /*
